//
//  AddCityController.m
//  CityGuide
//
//  Created by Alasdair Allan on 14/08/2009.
//  Copyright 2009 __MyCompanyName__. All rights reserved.
//

#import "AddCityController.h"
#import "CityGuideDelegate.h"
#import "RootController.h"
#import "City.h";
#import <sqlite3.h>;

@implementation AddCityController

#pragma mark ViewController Methods

- (void)didReceiveMemoryWarning {
	// Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
	
	// Release any cached data, images, etc that aren't in use.
}

- (void)viewDidLoad {
	self.title = @"New City";
	self.navigationItem.rightBarButtonItem = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemSave target:self action:@selector(saveCity:)];
	cityPicture = [UIImage imageNamed:@"QuestionMark.jpg"];
	pickerController = [[UIImagePickerController alloc] init];
	pickerController.allowsImageEditing = NO;
	pickerController.delegate = self;
	pickerController.sourceType = UIImagePickerControllerSourceTypeSavedPhotosAlbum;

}

- (void)viewDidUnload {
	// Release any retained subviews of the main view.
	// e.g. self.myOutlet = nil;
}


- (void)dealloc {
	[tableView release];
	[nameCell release];
	[pictureCell release];
	[descriptionCell release];
	[pickerController release];
    [super dealloc];
}

#pragma mark Instance Methods
- (void)saveCity:(id)sender {
	CityGuideDelegate *delegate = (CityGuideDelegate *)[[UIApplication sharedApplication] delegate];
	NSMutableArray *cities = delegate.cities;
	
	UITextField *nameEntry = (UITextField *)[nameCell viewWithTag:777];
	UITextView *descriptionEntry = (UITextView *)[descriptionCell viewWithTag:777];
	
	if ( nameEntry.text.length > 0 ) {
		City *newCity = [[City alloc] init];
		newCity.cityName = nameEntry.text;
		newCity.cityDescription = descriptionEntry.text;
		newCity.cityPicture = cityPicture;
		[cities addObject:newCity];
		[self addCityToDatabase:newCity];
		
		RootController *viewController = delegate.viewController;
		[viewController.tableView reloadData];
	}
	[delegate.navController popViewControllerAnimated:YES];
	
}

- (IBAction)addPicture:(id)sender {	
	UITextField *nameEntry = (UITextField *)[nameCell viewWithTag:777];
	[nameEntry resignFirstResponder];
	
	[self presentModalViewController:pickerController animated:YES];
}

#pragma mark Database Methods

-(void) addCityToDatabase:(City *)newCity {
	NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
    NSString *documentsPath = [paths objectAtIndex:0];
    NSString *filePath = [documentsPath stringByAppendingPathComponent:@"cities.sqlite"];
	
	sqlite3 *database;
	
	if(sqlite3_open([filePath UTF8String], &database) == SQLITE_OK) {
		const char *sqlStatement = "insert into cities (name, description, image) VALUES (?, ?, ?)";
		sqlite3_stmt *compiledStatement;
		if(sqlite3_prepare_v2(database, sqlStatement, -1, &compiledStatement, NULL) == SQLITE_OK) {
		    sqlite3_bind_text( compiledStatement, 1, [newCity.cityName UTF8String], -1, SQLITE_TRANSIENT);
			sqlite3_bind_text( compiledStatement, 2, [newCity.cityDescription UTF8String], -1, SQLITE_TRANSIENT);
			NSData *dataForPicture = UIImagePNGRepresentation(newCity.cityPicture);
			sqlite3_bind_blob( compiledStatement, 3, [dataForPicture bytes], [dataForPicture length], SQLITE_TRANSIENT);
			
		}
		if(sqlite3_step(compiledStatement) == SQLITE_DONE) {
	       	sqlite3_finalize(compiledStatement);
		}
	}
	sqlite3_close(database);
}


#pragma mark UIImagePickerController Methods

- (void)imagePickerController:(UIImagePickerController *)picker didFinishPickingMediaWithInfo:(NSDictionary *)info {
	[self dismissModalViewControllerAnimated:YES];

	cityPicture = [info objectForKey:@"UIImagePickerControllerOriginalImage"];	
	UIImageView *pictureView = (UIImageView *)[pictureCell viewWithTag:777];
	pictureView.image = cityPicture;	
	[tableView reloadData];
	
}

#pragma mark UITableViewDataSource Methods

- (UITableViewCell *)tableView:(UITableView *)tv cellForRowAtIndexPath:(NSIndexPath *)indexPath {
	UITableViewCell *cell = nil;
	if( indexPath.row == 0 ) {
		cell = nameCell;
	} else if ( indexPath.row == 1 ) {
		UIImageView *pictureView = (UIImageView *)[pictureCell viewWithTag:777];
		pictureView.image = cityPicture;
		cell = pictureCell;
	} else {
		cell = descriptionCell;
	}
	return cell;
	
}

- (NSInteger)tableView:(UITableView *)tv numberOfRowsInSection:(NSInteger)section {
	return 3;
}

#pragma mark UITableViewDelegate Methods

- (CGFloat)tableView:(UITableView *)tv heightForRowAtIndexPath:(NSIndexPath *)indexPath {
	CGFloat height;
	if( indexPath.row == 0 ) {
		height = 44;
	} else 	if( indexPath.row == 1 ) {
		height = 83;
	} else {
		height = 279;
	}
	return height;
	
}

@end
